/**
  ******************************************************************************
  * @file    CLK/CLK_SYSCLKSwitch/main.c
  * @author  MCD Application Team
  * @version V1.5.2
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "stm8_eval.h"
#include "stm8_eval_lcd.h"
#include "timing_delay.h"

 // @addtogroup STM8L15x_StdPeriph_Examples

 // @addtogroup CLK_SYSCLKSwitch

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
static void CLK_Config(void);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
   // CLK configuration -------------------------------------------
  CLK_Config(); 

  // Init TIM2 to generate 1 ms time base update interrupt 
  TimingDelay_Init();

  // Enable Interrupts 
  enableInterrupts();

  // Initialize LEDs mounted on STM8L152X-EVAL board 
  STM_EVAL_LEDInit(LED1);
  STM_EVAL_LEDInit(LED2);
  STM_EVAL_LEDInit(LED3);
  STM_EVAL_LEDInit(LED4);

  // Turn on LED1 and LED3 
  STM_EVAL_LEDOn(LED1);
  STM_EVAL_LEDOn(LED3);

  // Initialize push-buttons mounted on STM8L152X-EVAL board 
  STM_EVAL_PBInit(BUTTON_RIGHT, BUTTON_MODE_EXTI);
  STM_EVAL_PBInit(BUTTON_LEFT, BUTTON_MODE_EXTI);
  STM_EVAL_PBInit(BUTTON_UP, BUTTON_MODE_EXTI);
  STM_EVAL_PBInit(BUTTON_DOWN, BUTTON_MODE_EXTI);

  // Init the Eval board LCD 
  STM8_EVAL_LCD_Init();

  // Clear LCD 
  LCD_Clear();

  // Enable general interrupts 
  enableInterrupts();

  LCD_SetCursorPos(LCD_LINE1, 0);
  LCD_Print("  System Clock  ");
  LCD_SetCursorPos(LCD_LINE2, 0);
  LCD_Print("  Source:  HSE  ");

  while (1)
  {
    // Toggle LED2 and LED4 
    STM_EVAL_LEDToggle(LED2);
    STM_EVAL_LEDToggle(LED4);

    // Insert a delay 
    Delay(10);

    // Toggle LED1 and LED3 
    STM_EVAL_LEDToggle(LED1);
    STM_EVAL_LEDToggle(LED3);

    // Insert a delay 
    Delay(10);
  }
}

/**
  * @brief  Configure System Clock 
  * @param  None
  * @retval None
  */
static void CLK_Config(void)
{
  // Select HSE as system clock source 
  CLK_SYSCLKSourceSwitchCmd(ENABLE);
  CLK_SYSCLKSourceConfig(CLK_SYSCLKSource_HSE);
  // system clock prescaler: 1
  CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);
  while (CLK_GetSYSCLKSource() != CLK_SYSCLKSource_HSE)
  {}
}
#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */
  // Infinite loop 
  while (1)
  {}
}



#endif

