/**
  ******************************************************************************
  * @file    PWR/PWR_WFI/main.c
  * @author  MCD Application Team
  * @version V1.5.2
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "stm8_eval.h"

 // @addtogroup STM8L15x_StdPeriph_Examples

  // * @addtogroup PWR_WFI

// Private function prototypes -----------------------------------------------
// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------

// Private function prototypes -----------------------------------------------
static void RTC_Config(void);
void Delay(__IO uint32_t nCount);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
  // Initialize LEDs mounted on STM8L152X-EVAL board 
  STM_EVAL_LEDInit(LED1);
  STM_EVAL_LEDInit(LED2);
  STM_EVAL_LEDInit(LED3);
  STM_EVAL_LEDInit(LED4);

  // Initialize Key-button mounted on STM8L152X-EVAL board 
  STM_EVAL_PBInit(BUTTON_KEY, BUTTON_MODE_EXTI);

   // RTC configuration -------------------------------------------
  RTC_Config(); 

  // Infinite loop 
  while (1)
  {
    STM_EVAL_LEDOn(LED1);
    STM_EVAL_LEDOff(LED2);
    Delay(0xFFFF);
    STM_EVAL_LEDOn(LED2);
    STM_EVAL_LEDOff(LED1);

    // RTC will wake-up from halt every 5second 
    RTC_SetWakeUpCounter(5);
    RTC_WakeUpCmd(ENABLE);

    // Enter Wait for interrupt mode
    wfi();

    RTC_WakeUpCmd(DISABLE);
  }
}

/**
  * @brief  Configure RTC peripheral
  * @param  None
  * @retval None
  */
static void RTC_Config(void)
{
  // Configures the RTC 
  CLK_RTCClockConfig(CLK_RTCCLKSource_LSE, CLK_RTCCLKDiv_1);
  CLK_PeripheralClockConfig(CLK_Peripheral_RTC, ENABLE);
  
  RTC_WakeUpClockConfig(RTC_WakeUpClock_CK_SPRE_16bits);
  RTC_ITConfig(RTC_IT_WUT, ENABLE);

  // Enable Interrupts
  enableInterrupts();
}
/**
  * @brief  Inserts a delay time.
  * @param  nCount: specifies the delay time length.
  * @retval None
  */
void Delay(__IO uint32_t nCount)
{
  for (; nCount != 0; nCount--);
}

#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {}
}
#endif



