/**
  ******************************************************************************
  * @file   RTC/RTC_PeriodicWakeup500ms/main.c
  * @author  MCD Application Team
  * @version V1.5.2
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "stm8_eval.h"


 // @addtogroup RTC_PeriodicWakeup500ms

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
void RTC_Config(void);
void LSE_StabTime(void);

// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
  // Configures the LEDs GPIO port IOs and LCD peripheral
  STM_EVAL_LEDInit(LED1);
  STM_EVAL_LEDInit(LED2);
  STM_EVAL_LEDInit(LED3);
  STM_EVAL_LEDInit(LED4);

   // RTC configuration -------------------------------------------
  RTC_Config();

  // Leds are ON
  STM_EVAL_LEDOn(LED1);
  STM_EVAL_LEDOn(LED2);
  STM_EVAL_LEDOn(LED3);
  STM_EVAL_LEDOn(LED4);

  // RTC wake-up event every 500 ms (timer_step x (1023 + 1) )
  RTC_SetWakeUpCounter(1023);
  RTC_WakeUpCmd(ENABLE);

  while (1)
  {}

}
/**
  * @brief  Configure RTC peripheral 
  * @param  None
  * @retval None
  */
static void RTC_Config(void)
{
  // Enable RTC clock 
  CLK_RTCClockConfig(CLK_RTCCLKSource_LSE, CLK_RTCCLKDiv_1);
  // Wait for LSE clock to be ready 
  while (CLK_GetFlagStatus(CLK_FLAG_LSERDY) == RESET);
  // wait for 1 second for the LSE Stabilisation 
  LSE_StabTime();
  CLK_PeripheralClockConfig(CLK_Peripheral_RTC, ENABLE);

  // Configures the RTC wakeup timer_step = RTCCLK/16 = LSE/16 = 488.28125 us 
  RTC_WakeUpClockConfig(RTC_WakeUpClock_RTCCLK_Div16);

  // Enable wake up unit Interrupt 
  RTC_ITConfig(RTC_IT_WUT, ENABLE);

  // Enable general Interrupt
  enableInterrupts();
}
/**
  * @brief  Wait 1 sec for LSE stabilisation .
  * @param  None.
  * @retval None.
  * Note : TIM4 is configured for a system clock = 2MHz
  */
void LSE_StabTime(void)
{

  CLK_PeripheralClockConfig(CLK_Peripheral_TIM4, ENABLE);

  // Configure TIM4 to generate an update event each 1 s 
  TIM4_TimeBaseInit(TIM4_Prescaler_16384, 123);
  // Clear update flag 
  TIM4_ClearFlag(TIM4_FLAG_Update);

  // Enable TIM4 
  TIM4_Cmd(ENABLE);

  // Wait 1 sec 
  while ( TIM4_GetFlagStatus(TIM4_FLAG_Update) == RESET );

  TIM4_ClearFlag(TIM4_FLAG_Update);

  // Disable TIM4 
  TIM4_Cmd(DISABLE);

  CLK_PeripheralClockConfig(CLK_Peripheral_TIM4, DISABLE);
}
#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {}
}
#endif


