/**
  ******************************************************************************
  * @file    TIM1/TIM1_PWMInput/main.c
  * @author  MCD Application Team
  * @version V1.5.2
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

 // @addtogroup STM8L15x_StdPeriph_Examples

 // @addtogroup TIM1_PWMInput

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
uint8_t ICFilter = 0;
// Private function prototypes -----------------------------------------------
static void CLK_Config(void);
static void GPIO_Config(void);
static void TIM1_Config(void);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
   // CLK configuration -------------------------------------------
  CLK_Config(); 

   // GPIO configuration -------------------------------------------
  GPIO_Config(); 
  
   // TIM1 configuration -------------------------------------------
  TIM1_Config();
  
  // Infinite loop 
  while (1)
  {}
}

/**
  * @brief  Configure peripherals Clock   
  * @param  None
  * @retval None
  */
static void CLK_Config(void)
{
  // High speed internal clock prescaler: 1
  CLK_SYSCLKDivConfig(CLK_SYSCLKDiv_1);

  // Select HSE as system clock source 
  CLK_SYSCLKSourceSwitchCmd(ENABLE);
  CLK_SYSCLKSourceConfig(CLK_SYSCLKSource_HSE);

  while (CLK_GetSYSCLKSource() != CLK_SYSCLKSource_HSE)
  {}

  // Enable TIM1 clock 
  CLK_PeripheralClockConfig(CLK_Peripheral_TIM1, ENABLE);
}

/**
  * @brief  Configure TIM Channels GPIO 
  * @param  None
  * @retval None
  */
static void GPIO_Config(void)
{
  // GPIOD configuration: TIM1 channel 1 (PD2) 
  GPIO_Init(GPIOD, GPIO_Pin_2, GPIO_Mode_Out_PP_Low_Fast);
}

/**
  * @brief  Configure TIM1 peripheral 
  * @param  None
  * @retval None
  */
static void TIM1_Config(void)
{
  // configure TIM1 channel 1 to capture a PWM signal 
  TIM1_PWMIConfig(TIM1_Channel_1, TIM1_ICPolarity_Rising, TIM1_ICSelection_DirectTI,
                  TIM1_ICPSC_DIV1, ICFilter);

  // Select the TIM1 Input Trigger: TI1FP1 
  TIM1_SelectInputTrigger(TIM1_TRGSelection_TI1FP1);
  TIM1_SelectSlaveMode(TIM1_SlaveMode_Reset);

  // Enable CC1 interrupt request 
  TIM1_ITConfig(TIM1_IT_CC1, ENABLE);
  enableInterrupts();

  // Enable TIM1 
  TIM1_Cmd(ENABLE);
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {}
}
#endif



