/**
  ******************************************************************************
  * @file    TIM2/TIM2_TRIGLSE/main.c
  * @author  MCD Application Team
  * @version V1.5.2
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

 // @addtogroup STM8L15x_StdPeriph_Examples

 // @addtogroup TIM2_TRIGLSE

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
#define TIM2_PERIOD  (uint8_t) 7
#define TIM2_PULSE   (uint8_t) 4

// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
static void CLK_Config(void);
static void TIM2_Config(void);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
   // CLK configuration -------------------------------------------
  CLK_Config();

   // TIM2 configuration -------------------------------------------
  TIM2_Config();

  while (1)
  {}
}

/**
  * @brief  Configure peripherals Clock   
  * @param  None
  * @retval None
  */
static void CLK_Config(void)
{
  // Enable TIM2 clock 
  CLK_PeripheralClockConfig(CLK_Peripheral_TIM2, ENABLE);

  // TIM2 Channel1 configuration: PB0 
  GPIO_Init(GPIOB, GPIO_Pin_0, GPIO_Mode_Out_PP_Low_Fast);
  // Remap TIM2 ETR to LSE: TIM2 external trigger becomes controlled by LSE clock 
  SYSCFG_REMAPPinConfig(REMAP_Pin_TIM2TRIGLSE, ENABLE);

  // Enable LSE clock 
  CLK_LSEConfig(CLK_LSE_ON);
  // Wait for LSERDY flag to be reset 
  while (CLK_GetFlagStatus(CLK_FLAG_LSERDY) == RESET);
}

/**
  * @brief  Configure TIM2 peripheral   
  * @param  None
  * @retval None
  */
static void TIM2_Config(void)
{
  /* TIM2 configuration:
     - TIM2 ETR is mapped to LSE
     - TIM2 counter is clocked by LSE div 4
      so the TIM2 counter clock used is LSE / 4 = 32.768 / 4 = 8.192 KHz
    TIM2 Channel1 output frequency = TIM2CLK / (TIM2 Prescaler * (TIM2_PERIOD + 1))
                                   = 8192 / (1 * 8) = 1024 Hz */
  // Time Base configuration 
  TIM2_TimeBaseInit(TIM2_Prescaler_1, TIM2_CounterMode_Up, TIM2_PERIOD);
  TIM2_ETRClockMode2Config(TIM2_ExtTRGPSC_DIV4, TIM2_ExtTRGPolarity_NonInverted, 0);

  // Channel 1 configuration in PWM1 mode 
  // TIM2 channel Duty cycle is 100 * TIM2_PULSE / (TIM2_PERIOD + 1) = 100 * 4/8 = 50 % 
  TIM2_OC1Init(TIM2_OCMode_PWM1, TIM2_OutputState_Enable, TIM2_PULSE, TIM2_OCPolarity_Low, TIM2_OCIdleState_Set);

  // TIM2 Main Output Enable 
  TIM2_CtrlPWMOutputs(ENABLE);

  // TIM2 counter enable 
  TIM2_Cmd(ENABLE);
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */
  // Infinite loop 
  while (1)
  {}
}
#endif



